claguard

package
v0.0.0-...-875a40c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 3, 2026 License: Apache-2.0 Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Check

func Check(ownClaims []string, wantClaims []string) bool

Check checks if the own claims contain any of the wanted claims Returns true if any of the wanted claims is found in the own claims Returns false if none of the wanted claims is found in the own claims

func CheckSingle

func CheckSingle(ownClaims []string, wantClaim string) bool

CheckSingle checks if the own claims contain the wanted claim Returns true if the wanted claim is found in the own claims Returns false if the wanted claim is not found in the own claims

Types

This section is empty.

Jump to