cqrs

package
v0.0.0-...-875a40c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 3, 2026 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Empty

type Empty struct{}

Empty is a type that can be used as a placeholder for empty cqrs responses

type Handler

type Handler[TParams any, TResponse any] interface {
	Handle(context.Context, TParams) (TResponse, error)
}

Handler is an interface that must be implemented by all command handlers It is used to execute a command The command handler must implement this interface

type HandlerFunc

type HandlerFunc[TParams any, TResponse any] func(context.Context, TParams) (TResponse, error)

HandlerFunc is a function that can be used as a Handler It is used to convert a function to a Handler

Jump to