Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( ValidationFailed = New(1000, http.StatusUnprocessableEntity, "validation_failed") Failed = New(1001, http.StatusInternalServerError, "failed") NotFound = New(1002, http.StatusNotFound, "not_found") )
Functions ¶
This section is empty.
Types ¶
type R ¶
type R map[string]interface{}
any is a type alias for interface{}. It is used to store any type of data.
type RC ¶
type RC struct {
// Code is the code of the error.
Code uint64
// Message is the message of the error.
Message string
// StatusCode is the http/rpc status code of the error.
StatusCode int
// Data is the data of the error.
Data any
// contains filtered or unexported fields
}
RC is a struct that contains the code, message, http status, and translateable. Code is the code of the error.
func (*RC) OriginalError ¶
Click to show internal directories.
Click to hide internal directories.