Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Listener ¶
type Listener interface {
// Listen is used to listen for requests
// The Listen method returns an error
// The error is nil if the server is listening successfully
Listen() error
}
Server is the interface that must be implemented by a server It is used to listen for requests The Listen method is used to listen for requests The Listen method returns an error The error is nil if the server is listening successfully
Click to show internal directories.
Click to hide internal directories.