Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Check ¶
Check checks if the own claims contain any of the wanted claims Returns true if any of the wanted claims is found in the own claims Returns false if none of the wanted claims is found in the own claims
func CheckSingle ¶
CheckSingle checks if the own claims contain the wanted claim Returns true if the wanted claim is found in the own claims Returns false if the wanted claim is not found in the own claims
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.